<div align="center">

# Haaaash
hash 批量计算器

![PyPI - Version](https://img.shields.io/pypi/v/haaaash?label=PyPI) ![PyPI - License](https://img.shields.io/pypi/l/haaaash) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/haaaash) [![PyPI - Downloads](https://img.shields.io/pypi/dm/haaaash?label=PyPI%20Download)
](https://pypi.org/project/haaaash/)

</div>

## Install
使用 `pip install haaaash` 安装。

## Docs
通过 `haaaash -h` 查看帮助信息。

或者查看 [![Docs](https://img.shields.io/badge/Docs-blue)
](https://haaaash.gudupao.top)
